
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

###############################
Sample usage for treetransforms
###############################

.. include:: ../../nltk/test/treetransforms.doctest